@@ -1,4 +1,4 @@
-/* $Id: display_plugin.c 6375 2004-12-27 19:05:36Z pollux $ */
+/* $Id: display_plugin.c 16059 2005-06-25 10:54:54Z benny $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  *
@@ -290,15 +290,17 @@ mcs_plugin_init (McsPlugin * plugin)
 static gboolean
 save_settings (McsPlugin * plugin)
 {
-    gboolean result;
+    gboolean result = FALSE;
     gchar *rcfile, *path;
 
     path = g_build_filename ("xfce4", RCDIR, RCFILE, NULL);
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);
-    result = mcs_manager_save_channel_to_file(plugin->manager, CHANNEL, 
-                                              rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result = mcs_manager_save_channel_to_file (plugin->manager, CHANNEL, rcfile);
+        g_free(rcfile);
+    }
     g_free(path);
-    g_free(rcfile);
 
     return (result);
 }
