@@ -613,22 +613,26 @@ create_channel(McsPlugin *mcs_plugin)
 static gboolean
 write_options(McsPlugin *mcs_plugin)
 {
-    gboolean result;
+    gboolean result = FALSE;
     gchar *rcfile, *path;
 
     path = g_build_filename ("xfce4", RCDIR, RCFILE1, NULL);    
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);
-    result = mcs_manager_save_channel_to_file(mcs_plugin->manager, CHANNEL1,
-                    rcfile);
-    g_free(path);
-    g_free(rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL1, rcfile);
+        g_free (rcfile);
+    }
+    g_free (path);
 
     path = g_build_filename ("xfce4", RCDIR, RCFILE2, NULL);    
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);
-    result = mcs_manager_save_channel_to_file(mcs_plugin->manager, CHANNEL2,
-                    rcfile);
-    g_free(path);
-    g_free(rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result &= mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL2, rcfile);
+        g_free (rcfile);
+    }
+    g_free (path);
 
     return(result);
 }
