@@ -1205,7 +1205,7 @@ static void create_channel(McsPlugin * mcs_plugin)
             g_free(current_icon_theme);
         }
 
-        current_icon_theme = g_strdup(DEFAULT_ICON_THEME);
+        current_icon_theme = g_strdup(INITIAL_ICON_THEME);
         mcs_manager_set_string(mcs_plugin->manager, "Net/IconThemeName", CHANNEL, current_icon_theme);
     }
 
@@ -1306,15 +1306,17 @@ static void create_channel(McsPlugin * mcs_plugin)
 
 static gboolean write_options(McsPlugin * mcs_plugin)
 {
-    gboolean result;
+    gboolean result = FALSE;
     gchar *rcfile, *path;
 
     path = g_build_filename ("xfce4", RCDIR, RCFILE, NULL);
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);
-    result = mcs_manager_save_channel_to_file(mcs_plugin->manager, CHANNEL, 
-                                              rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL, rcfile);
+        g_free(rcfile);
+    }
     g_free(path);
-    g_free(rcfile);
 
     return (result);
 }
@@ -1329,29 +1331,32 @@ static void apply_xft_options(Itf * itf)
                                        "xfce4" G_DIR_SEPARATOR_S "Xft.xrdb",
                                        TRUE);
 
-    if(!g_file_test(path, G_FILE_TEST_IS_REGULAR))
+    if (G_LIKELY (path != NULL))
     {
-        xfce_info(_("You have changed font rendering settings. This change will " "only affect newly started applications."));
-    }
+        if(!g_file_test(path, G_FILE_TEST_IS_REGULAR))
+        {
+            xfce_info(_("You have changed font rendering settings. This change will " "only affect newly started applications."));
+        }
 
-    fp = fopen(path, "w");
-    if(fp != NULL)
-    {
-        fprintf(fp, "Xft.antialias: %d\n", current_xft_antialias);
-        fprintf(fp, "Xft.hinting: %d\n", current_xft_hinting);
-        if(current_xft_hinting)
-            fprintf(fp, "Xft.hintstyle: %s\n", current_xft_hintstyle);
-        else
-            fprintf(fp, "Xft.hintstyle: hintnone\n");
-        fprintf(fp, "Xft.rgba: %s\n", current_xft_rgba);
-        fclose(fp);
+        fp = fopen(path, "w");
+        if(fp != NULL)
+        {
+            fprintf(fp, "Xft.antialias: %d\n", current_xft_antialias);
+            fprintf(fp, "Xft.hinting: %d\n", current_xft_hinting);
+            if(current_xft_hinting)
+                fprintf(fp, "Xft.hintstyle: %s\n", current_xft_hintstyle);
+            else
+                fprintf(fp, "Xft.hintstyle: hintnone\n");
+            fprintf(fp, "Xft.rgba: %s\n", current_xft_rgba);
+            fclose(fp);
 
-        /* run xrdb to merge the new settings */
-        cmd = g_strdup_printf("xrdb -nocpp -merge \"%s\"", path);
-        g_spawn_command_line_async(cmd, NULL);
-        g_free(cmd);
+            /* run xrdb to merge the new settings */
+            cmd = g_strdup_printf("xrdb -nocpp -merge \"%s\"", path);
+            g_spawn_command_line_async(cmd, NULL);
+            g_free(cmd);
+        }
+        g_free(path);
     }
-    g_free(path);
 }
 
 static void run_dialog(McsPlugin * mcs_plugin)
